@@ -17,7 +17,7 @@ start:\
     rejected_atoms\
     dist_repeated_target\
     time_order_analysis\
-    frequencies\
+    frequencies+\
     nondisplacive
 
 // cascade/report.mfs RPRT4790
