@@ -31,10 +31,12 @@ float: _S? SIGNED_FLOAT _S? -> float // float with left and right padding
 pfloat: SIGNED_FLOAT -> float // float without padding
 '''
 
+
+
 fixedwidth_int_values = [2, 3, 4, 5, 6]
 def gen_fixedwidth_int_grammar(width):
-    return f'''FWINT{width:d}: /([ \\d-]{{{width-1:d}}}\\d)|(\\*{{{width:d}}})/
-    fwint{width:d}: FWINT{width:d} -> fwint{width:d}'''
+    return f'''FWINT{width:d}: /([+-]\\d{{{width-1:d}}})|(\\d{{{width:d}}})|(\\*{{{width:d}}})/
+    fwint{width:d}: (_S SIGNED_INT) | FWINT{width:d} -> fwint{width:d}'''
 
 grammar_fixedwidth_int = '\n'.join([gen_fixedwidth_int_grammar(i) for i in fixedwidth_int_values])
 
